@@ -1,4 +1,4 @@
-fr_agencies <- function(id=NULL, version='v1'){
+fr_agencies <- function(id=NULL, version='v1', ...){
     if(is.null(id))
         baseurl <- paste('https://www.federalregister.gov/api/',version,'/agencies', sep='')
     else
@@ -6,12 +6,9 @@ fr_agencies <- function(id=NULL, version='v1'){
     
     args <- NULL
     
-    h <- basicTextGatherer()
-    curlPerform(url = paste(baseurl, args, sep=''),
-                followlocation = 1L, ssl.verifypeer = 1L, ssl.verifyhost = 2L, 
-                cainfo = system.file("CurlSSL", "cacert.pem", package = "RCurl"),
-                writefunction=h$update)
-    response <- h$value()
+    r <- GET(url = paste(baseurl, args, sep=''), ...)
+    stop_for_status(r)
+    response <- content(r, "text")
     out <- fromJSON(response)
     if(length(id)==1){
         class(out) <- 'fedreg_agency'
